#
# spec file for package python-aioftp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python2 1
Name:           python-aioftp
Version:        0.21.4
Release:        2.8
Summary:        FTP client/server for asyncio
License:        Apache-2.0
URL:            https://github.com/aio-libs/aioftp
Source:         https://files.pythonhosted.org/packages/source/a/aioftp/aioftp-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-siosocks >= 0.2.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module async_timeout}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module siosocks >= 0.2.0}
BuildRequires:  %{python_module trustme}
# /SECTION
%python_subpackages

%description
aioftp is a python FTP client/server based on asyncio.

%prep
%setup -q -n aioftp-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license license.txt
%{python_sitelib}/aioftp-%{version}*-info
%{python_sitelib}/aioftp

%changelog
* Sat Jan  7 2023 Ben Greiner <code@bnavigator.de>
- Remove 'legacy' pytest-asyncio mode command line argument. It is
  not available anymore, meanwhile upstream uses 'strict' from
  config file.
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.21.4
  * setup/tests: set low bound for version of `async-timeout`
  * docs: fix rst link markup
  * docs: add `LIST` parsing warning explanation
  * tests: use `pytest_asyncio` `strict` mode and proper decorations (fixes #155)
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.21.3
  * server/LIST: prevent broken links are listed, but can't be used
    with stat
  * server: make User.get_permissions async
- Release 0.21.2
  + tests: remove exception representation check
- Release 0.21.1
  * tests: replace more specific ConnectionRefusedError with
    OSError for compatibility with FreeBSD (#152)
- Release 0.21.0
  * server: support PASV response with custom address (#150)
- Release 0.20.1
  * server: fix real directory resolve for windows (#147)
- Release 0.20.0
  * add client argument to set priority of custom list parser
    (parse_list_line_custom_first) (#145)
  * do not ignore failed parsing of list response (#144)
- Enforce legacy pytest-asyncio mode
  * gh#aio-libs/aioftp#155
  * works around gh#pytest-dev/pytest-asyncio#390
* Wed Nov  3 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.19.0
  * add client connection timeout
  * remove explicit coroutine passing to `asyncio.wait`
* Fri Jan 22 2021 andy great <andythe_great@pm.me>
- Add minimum python-siosocks version.
* Thu Jan 21 2021 andy great <andythe_great@pm.me>
- Update to 0.18.1.
  * sync tests with new `siosocks`
  * some docs fixes
- Updates for 0.18.0
  * server: fix `MLSX` time format
  * server: resolve server address from connection
- Updates for 0.17.2
  * server: fix broken `python -m aioftp` after 3.7 migration
- Updates for 0.17.1
  * common/stream: add `readexactly` proxy method
- Updates for 0.17.0
  * tests: fix test_unlink_on_dir on POSIX compatible systems
  * docs: fix extra parentheses
  * client: replace `ClientSession` with `Client.context`
- Updates for 0.16.1
  * client: strip date before parsing
  * client: logger no longer prints out plaintext password
  * client: add custom passive commands to client
- Updates for 0.16.0
  * server: remove obsolete `pass` to `pass_` command renaming
  * client: fix leap year bug at `parse_ls_date` method
  * all: add base exception class
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.15.0
  * server: use explicit mapping of available commands for security reasons
  * client: add socks proxy support via siosocks
  * client: add custom list parser
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Initial version
